From: SeongJae Park <sj@kernel.org>
Cc: SeongJae Park <sj@kernel.org>,
damon@lists.linux.dev, linux-kernel@vger.kernel.org,
linux-mm@kvack.org
Subject: [RFC PATCH v3 28/37] mm/damon: extend damon_sample_filter for threads
Date: Sun, 7 Dec 2025 22:29:32 -0800 [thread overview]
Message-ID: <20251208062943.68824-29-sj@kernel.org> (raw)
In-Reply-To: <20251208062943.68824-1-sj@kernel.org>
Now DAMON access reports could inform which thread was making the
reporting access. By filtering the reports based on the threads, DAMON
can do per-threads monitoring. Extend DAMON access sample filter to do
such filtering.
Signed-off-by: SeongJae Park <sj@kernel.org>
---
include/linux/damon.h | 19 +++++++++++++++----
1 file changed, 15 insertions(+), 4 deletions(-)
diff --git a/include/linux/damon.h b/include/linux/damon.h
index 80332bb2b73c..e3408280ea72 100644
--- a/include/linux/damon.h
+++ b/include/linux/damon.h
@@ -787,11 +787,13 @@ struct damon_primitives_enabled {
* enum damon_sample_filter_type - Type of &struct damon_sample_filter.
*
* @DAMON_FILTER_TYPE_CPUMASK: Filter by access-generated CPUs.
+ * @DAMON_FILTER_TYPE_THREADS: Filter by access-generated threads.
*
* Read &struct damon_sample_control for more details.
*/
enum damon_sample_filter_type {
DAMON_FILTER_TYPE_CPUMASK,
+ DAMON_FILTER_TYPE_THREADS,
};
/**
@@ -801,6 +803,9 @@ enum damon_sample_filter_type {
* @matching: Whether it is for condition-matching reports.
* @allow: Whether to include or excludie the @matching reports.
* @cpumask: Access-generated CPUs if @type is DAMON_FILTER_TYPE_CPUMASK.
+ * @tid_arr: Array of access-generated thread ids, if @type is
+ * DAMON_FILTER_TYPE_THREADS.
+ * @nr_tids: Size of @tid_arr, if @type is DAMON_FILTER_TYPE_THREADS.
* @list: List head for siblings.
*
* Read &struct damon_sample_control for more details.
@@ -809,7 +814,13 @@ struct damon_sample_filter {
enum damon_sample_filter_type type;
bool matching;
bool allow;
- cpumask_t cpumask;
+ union {
+ cpumask_t cpumask;
+ struct {
+ pid_t *tid_arr;
+ int nr_tids;
+ };
+ };
struct list_head list;
};
@@ -823,9 +834,9 @@ struct damon_sample_filter {
* that to make higher access pattern picture. It can use multiple sampling
* primitives including page table accessed bits and page fault events. It can
* also filter in/out specific types of sampled access events to monitor
* accesses of specific types, such as access-generated CPUs. This struct is
* for controlling what sampling primitives to use (enable), and what sampled
* access events should be filtered in/out.
*/
struct damon_sample_control {
struct damon_primitives_enabled primitives_enabled;
@@ -823,9 +834,9 @@ struct damon_sample_filter {
* primitives including page table accessed bits and page fault events. It can
* also filter in/out specific types of sampled access events to monitor
- * accesses of specific types, such as access-generated CPUs. This struct is
- * for controlling what sampling primitives to use (enable), and what sampled
- * access events should be filtered in/out.
+ * accesses of specific types, such as access-generated CPUs and threads. This
+ * struct is for controlling what sampling primitives to use (enable), and what
+ * sampled access events should be filtered in/out.
*/
struct damon_sample_control {
--
2.47.3
next prev parent reply other threads:[~2025-12-08 6:30 UTC|newest]
Thread overview: 52+ messages / expand[flat|nested] mbox.gz Atom feed top
2025-12-08 6:29 [RFC PATCH v3 00/37] mm/damon: introduce per-CPUs/threads/write/read monitoring SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 01/37] mm/damon/core: implement damon_report_access() SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 02/37] mm/damon: define struct damon_sample_control SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 03/37] mm/damon/core: commit damon_sample_control SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 04/37] mm/damon/core: implement damon_report_page_fault() SeongJae Park
2025-12-12 12:46 ` JaeJoon Jung
2025-12-12 22:47 ` SeongJae Park
2025-12-13 0:31 ` JaeJoon Jung
2025-12-13 0:56 ` SeongJae Park
2025-12-13 1:37 ` JaeJoon Jung
2025-12-08 6:29 ` [RFC PATCH v3 05/37] mm/{mprotect,memory}: (no upstream-aimed hack) implement MM_CP_DAMON SeongJae Park
2025-12-08 11:19 ` David Hildenbrand (Red Hat)
2025-12-09 4:56 ` SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 06/37] mm/damon/paddr: support page fault access check primitive SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 07/37] mm/damon/core: apply access reports to high level snapshot SeongJae Park
2025-12-12 13:20 ` JaeJoon Jung
2025-12-12 23:11 ` SeongJae Park
2025-12-13 1:10 ` JaeJoon Jung
2025-12-13 3:21 ` SeongJae Park
2025-12-13 4:09 ` JaeJoon Jung
2025-12-13 5:53 ` SeongJae Park
2025-12-13 9:17 ` SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 08/37] mm/damon/sysfs: implement monitoring_attrs/sample/ dir SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 09/37] mm/damon/sysfs: implement sample/primitives/ dir SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 10/37] mm/damon/sysfs: connect primitives directory with core SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 11/37] Docs/mm/damon/design: document page fault sampling primitive SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 12/37] Docs/admin-guide/mm/damon/usage: document sample primitives dir SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 13/37] mm/damon: extend damon_access_report for origin CPU reporting SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 14/37] mm/damon/core: report access origin cpu of page faults SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 15/37] mm/damon: implement sample filter data structure for cpus-only monitoring SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 16/37] mm/damon/core: implement damon_sample_filter manipulations SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 17/37] mm/damon/core: commit damon_sample_filters SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 18/37] mm/damon/core: apply sample filter to access reports SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 19/37] mm/damon/sysfs: implement sample/filters/ directory SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 20/37] mm/damon/sysfs: implement sample filter directory SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 21/37] mm/damon/sysfs: implement type, matching, allow files under sample filter dir SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 22/37] mm/damon/sysfs: implement cpumask file " SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 23/37] mm/damon/sysfs: connect sample filters with core layer SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 24/37] Docs/mm/damon/design: document sample filters SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 25/37] Docs/admin-guide/mm/damon/usage: document sample filters dir SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 26/37] mm/damon: extend damon_access_report for access-origin thread info SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 27/37] mm/damon/core: report access-generated thread id of the fault event SeongJae Park
2025-12-08 6:29 ` SeongJae Park [this message]
2025-12-08 6:29 ` [RFC PATCH v3 29/37] mm/damon/core: support threads type sample filter SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 30/37] mm/damon/sysfs: support thread based access sample filtering SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 31/37] Docs/mm/damon/design: document threads type sample filter SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 32/37] Docs/admin-guide/mm/damon/usage: document tids_arr file SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 33/37] mm/damon: support reporting write access SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 34/37] mm/damon/core: report whether the page fault was for writing SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 35/37] mm/damon/core: support write access sample filter SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 36/37] mm/damon/sysfs: support write-type " SeongJae Park
2025-12-08 6:29 ` [RFC PATCH v3 37/37] Docs/mm/damon/design: document write access sample filter type SeongJae Park
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20251208062943.68824-29-sj@kernel.org \
--to=sj@kernel.org \
--cc=damon@lists.linux.dev \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-mm@kvack.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.